==> pypaws-0.7.1.tar.gz: pypaws-0.7.1/paws/core/operations/PROCESSING/BASIC/Rotation.py <==
import numpy as np

from ... import Operation as op
from ...Operation import Operation

class Rotation(Operation):
    """Rotate an array by 90, 180, or 270 degrees."""

    def __init__(self):
        input_names = ['image_data','rotation_deg']
        output_names = ['image_data']
        super(Rotation,self).__init__(input_names,output_names)        
        self.input_src['rotation_deg'] = op.text_input
        self.input_type['rotation_deg'] = op.int_type
        self.input_doc['image_data'] = '2d array representing intensity for each pixel'
        self.input_doc['rotation_deg'] = str('rotation in degrees counter-clockwise, '
                                    + 'must be either 90, 180, or 270')
        self.output_doc['image_data'] = '2d array representing rotated image'
        self.input_src['image_data'] = op.wf_input
        self.input_src['rotation_deg'] = op.text_input
        self.input_type['rotation_deg'] = op.int_type
        self.inputs['rotation_deg'] = 90 

    def run(self):
        """Rotate self.inputs['image_data'] and save as self.outputs['image_data']"""
        img = np.array(self.inputs['image_data'])
        rot_deg = int(self.inputs['rotation_deg'])
        if rot_deg==90:
            img_rot = np.rot90(img)
        elif rot_deg==180:
            img_rot = np.rot90(np.rot90(img))
        elif rot_deg==270:
            img_rot = np.rot90(np.rot90(np.rot90(img)))
        else:
            msg = '[{}] expected rot_deg = 90, 180, or 270, got {}'.format(__name__,rot_deg)
            raise ValueError(msg)
        # save results to self.outputs
        self.outputs['image_data'] = img_rot

==> pypaws-0.7.4.tar.gz: pypaws-0.7.4/paws/core/operations/PROCESSING/BASIC/Rotation.py <==
import numpy as np

from ... import Operation as opmod 
from ...Operation import Operation

class Rotation(Operation):
    """Rotate an array by 90, 180, or 270 degrees."""

    def __init__(self):
        input_names = ['image_data','rotation_deg']
        output_names = ['image_data']
        super(Rotation,self).__init__(input_names,output_names)        
        self.input_src['rotation_deg'] = opmod.text_input
        self.input_type['rotation_deg'] = opmod.int_type
        self.input_doc['image_data'] = '2d array representing intensity for each pixel'
        self.input_doc['rotation_deg'] = str('rotation in degrees counter-clockwise, '
                                    + 'must be either 90, 180, or 270')
        self.output_doc['image_data'] = '2d array representing rotated image'
        self.input_src['image_data'] = opmod.wf_input
        self.input_src['rotation_deg'] = opmod.text_input
        self.input_type['rotation_deg'] = opmod.int_type
        self.inputs['rotation_deg'] = 90 

    def run(self):
        """Rotate self.inputs['image_data'] and save as self.outputs['image_data']"""
        img = np.array(self.inputs['image_data'])
        rot_deg = int(self.inputs['rotation_deg'])
        if rot_deg==90:
            img_rot = np.rot90(img)
        elif rot_deg==180:
            img_rot = np.rot90(np.rot90(img))
        elif rot_deg==270:
            img_rot = np.rot90(np.rot90(np.rot90(img)))
        else:
            msg = '[{}] expected rot_deg = 90, 180, or 270, got {}'.format(__name__,rot_deg)
            raise ValueError(msg)
        # save results to self.outputs
        self.outputs['image_data'] = img_rot
